
local MakePlayerCharacter = require "prefabs/player_common"


local assets = {

        Asset( "ANIM", "anim/player_basic.zip" ),
        Asset( "ANIM", "anim/player_idles_shiver.zip" ),
        Asset( "ANIM", "anim/player_actions.zip" ),
        Asset( "ANIM", "anim/player_actions_axe.zip" ),
        Asset( "ANIM", "anim/player_actions_pickaxe.zip" ),
        Asset( "ANIM", "anim/player_actions_shovel.zip" ),
        Asset( "ANIM", "anim/player_actions_blowdart.zip" ),
        Asset( "ANIM", "anim/player_actions_eat.zip" ),
        Asset( "ANIM", "anim/player_actions_item.zip" ),
        Asset( "ANIM", "anim/player_actions_uniqueitem.zip" ),
        Asset( "ANIM", "anim/player_actions_bugnet.zip" ),
        Asset( "ANIM", "anim/player_actions_fishing.zip" ),
        Asset( "ANIM", "anim/player_actions_boomerang.zip" ),
        Asset( "ANIM", "anim/player_bush_hat.zip" ),
        Asset( "ANIM", "anim/player_attacks.zip" ),
        Asset( "ANIM", "anim/player_idles.zip" ),
        Asset( "ANIM", "anim/player_rebirth.zip" ),
        Asset( "ANIM", "anim/player_jump.zip" ),
        Asset( "ANIM", "anim/player_amulet_resurrect.zip" ),
        Asset( "ANIM", "anim/player_teleport.zip" ),
        Asset( "ANIM", "anim/wilson_fx.zip" ),
        Asset( "ANIM", "anim/player_one_man_band.zip" ),
        Asset( "ANIM", "anim/shadow_hands.zip" ),
        Asset( "SOUND", "sound/sfx.fsb" ),
        Asset( "SOUND", "sound/wilson.fsb" ),
        Asset( "ANIM", "anim/beard.zip" ),
		Asset( "IMAGE", "images/hud/starfox.tex" ),
        Asset( "ATLAS", "images/hud/starfox.xml" ), 

        Asset( "ANIM", "anim/fox.zip" ),
}
local prefabs = 
{
    "foxfur",
	"krystalstaff",
}
local start_inv = {}

	-- Custom starting items

local fn = function(inst)

    inst:AddComponent("beard")
    inst.components.beard.onreset = function()
        inst.AnimState:ClearOverrideSymbol("beard")
    end
    inst.components.beard.prize = "foxfur"
    
    --tune the beard economy...
	local beard_days = {4, 8, 12}
	local beard_bits = {1, 2,  3}
	
    inst.components.beard:AddCallback(beard_days[1], function()
        inst.AnimState:OverrideSymbol("beard", "fox_beard", "beard_short")
        inst.components.beard.bits = beard_bits[1]
    end)
    
    inst.components.beard:AddCallback(beard_days[2], function()
        inst.AnimState:OverrideSymbol("beard", "fox_beard", "beard_medium")
        inst.components.beard.bits = beard_bits[2]
    end)
    
    inst.components.beard:AddCallback(beard_days[3], function()
        inst.AnimState:OverrideSymbol("beard", "fox_beard", "beard_long")
        inst.components.beard.bits = beard_bits[3]
    end)
	
	-- choose which sounds this character will play
	inst.soundsname = "wilson"

	-- Minimap icon
	inst.MiniMapEntity:SetIcon( "fox.tex" )
	
	-- Nightvision
	inst.entity:AddLight()
	inst.Light:Enable(true)
	inst.Light:SetRadius(.4)
	inst.Light:SetFalloff(.1)
	inst.Light:SetIntensity(.1)
	inst.Light:SetColour(245/255,40/255,0/255)
	inst.components.health.fire_damage_scale = 2.0
	
	-- Stats	
	inst.components.health:SetMaxHealth(130)
	inst.components.hunger:SetMax(130)
	inst.components.sanity:SetMax(170)
	inst.components.temperature.hurtrate = (TUNING.WILSON_HEALTH / TUNING.FREEZING_KILL_TIME) / 2
	inst.components.sanity.night_drain_mult = .5
	
	-- Damage multiplier
    inst.components.combat.damagemultiplier = 1.25
	
	-- Hunger rate
	inst.components.hunger.hungerrate = 1.25 * TUNING.WILSON_HUNGER_RATE
	
	-- Movement speed
	inst.components.locomotor.walkspeed = 5
	inst.components.locomotor.runspeed = 7
	
	--StarFox Tab
	STRINGS.TABS.Starfox = "StarFox"
	local starfoxtab = {str = "StarFox", sort=448, icon = "starfox.tex", icon_atlas = "images/hud/starfox.xml"}
	inst.components.builder:AddRecipeTab(starfoxtab)
	
	--Extra Items
	local foxfur = Ingredient( "foxfur", 1)
	foxfur.atlas = "images/inventoryimages/foxfur.xml"
	
	local krystalstaff = Ingredient( "krystalstaff", 2)
	krystalstaff.atlas = "images/inventoryimages/krystalstaff.xml"
	
	local BeardHairRecipe = Recipe("BeardHair", {Ingredient("foxfur", 1)}, starfoxtab, {SCIENCE = 0, MAGIC = 0, ANCIENT = 0})
	BeardHairRecipe.atlas = "images/inventoryimages/foxfur.xml"
	
	local krystalstaffRecipe = Recipe("krystalstaff", {Ingredient("goldnugget", 2), Ingredient("purplegem", 1), Ingredient("spear", 1)}, starfoxtab, {SCIENCE = 2, MAGIC = 0, ANCIENT = 0})
	krystalstaff.atlas = "images/inventoryimages/krystalstaff.xml"
end



return MakePlayerCharacter("fox", prefabs, assets, fn, start_inv)